## ----setup, include=F---------------------------------------------------------
knitr::opts_chunk$set(eval=TRUE)
devtools::load_all(".")

## ----start--------------------------------------------------------------------
library(ggseg)
library(magrittr)
library(dplyr)
ggseg()

## ----void, fig.width=5--------------------------------------------------------
ggseg() + theme_void()

## ----stacked, fig.width=5-----------------------------------------------------
ggseg(position="stacked") +
  theme_void()

## ----fill, fig.width=5--------------------------------------------------------
ggseg(mapping=aes(fill=area)) +
  theme_void()

## ----fill2, fig.width=5-------------------------------------------------------
ggseg(colour="black", size=.7, mapping=aes(fill=area)) +
  theme_void()

## ----hemisphere, fig.width=5--------------------------------------------------
ggseg(hemisphere="right") +
  theme_void()

## ----datasupp, fig.width=5----------------------------------------------------
someData = data.frame(
  area = c("transverse temporal", "insula",
           "pre central","superior parietal"), 
  p = sample(seq(0,.5,.001), 4),
  stringsAsFactors = FALSE)

ggseg(.data=someData, mapping=aes(fill=p))


## ----datasupp2, fig.width=5---------------------------------------------------
ggseg(.data=someData, colour="black", mapping=aes(fill=p)) +
  theme_void() +
  scale_fill_gradient(low="firebrick",high="goldenrod") +
  labs(title="Aparc plots rule", fill="p-value")


## ----datasuppX, fig.width=5---------------------------------------------------
someData$hemi = "right"

ggseg(.data=someData, colour="white",mapping=aes(fill=p)) +
  theme_void() +
  scale_fill_gradient(low="firebrick",high="goldenrod") +
  labs(title="Aparc plots rule")


## ----datasupp3, fig.width=5---------------------------------------------------
someData = data.frame(
  area = rep(c("transverse temporal", "insula",
               "pre central","superior parietal"),2), 
  p = sample(seq(0,.5,.001), 8),
  AgeG = c(rep("Young",4), rep("Old",4)),
  stringsAsFactors = FALSE)
  
ggseg(.data=someData, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")


## ----duplicate, fig.width=5---------------------------------------------------
someData = someData %>% 
  group_by(AgeG)

ggseg(.data = someData, atlas=dkt, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")

## -----------------------------------------------------------------------------
vignette("externalData")

## ----datasupp4, fig.width=5---------------------------------------------------
ggseg(.data = someData, atlas=dkt, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme_dark() +
  theme(legend.position = "bottom",
        axis.text = element_blank(),
        axis.title = element_blank()
        ) +
  scale_fill_continuous(na.value="transparent")


## ----datasupp5, fig.width=5---------------------------------------------------
ggseg(.data = someData, atlas=dkt, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme_dark() +
  theme(legend.position = "bottom",
        axis.text = element_blank(),
        axis.title = element_blank()
        ) +
  scale_fill_gradient2(high="goldenrod",low="firebrick",na.value="transparent")


## ----atlases, fig.width=5-----------------------------------------------------
ggseg(atlas="aseg", mapping=aes(fill=area))

